aboutsummaryrefslogtreecommitdiffstats
path: root/tap-wspstat.c
diff options
context:
space:
mode:
authorAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
committerAnders Broman <anders.broman@ericsson.com>2006-05-28 20:28:20 +0000
commitf68d6e4c8cc08f1fe570d15e2185d339c81883b8 (patch)
tree2b6a6711cc2ff394c41a98f47a388466a433bccd /tap-wspstat.c
parent996d4db495e60df8a627097e3885acdce209132c (diff)
Ethereal->Wireshark
svn path=/trunk/; revision=18235
Diffstat (limited to 'tap-wspstat.c')
-rw-r--r--tap-wspstat.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/tap-wspstat.c b/tap-wspstat.c
index f6e2efe871..b99061dc01 100644
--- a/tap-wspstat.c
+++ b/tap-wspstat.c
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
/* This module provides WSP statistics to tethereal.
* It is only used by tethereal and not ethereal
*
*/
@@ -168,10 +168,10 @@ wspstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const
}
/* This callback is used when tethereal wants us to draw/update our
* data to the output device. Since this is tethereal only output is
* stdout.
* Tethereal will only call this callback once, which is when tethereal has
* finished reading all packets and exists.
* If used with wireshark this may be called any time, perhaps once every 3
* seconds or so.
@@ -209,7 +209,7 @@ wspstat_draw(void *psp)
/* When called, this function will create a new instance of wspstat.
* program and version are whick onc-rpc program/version we want to
* collect statistics for.
* This function is called from tethereal when it parses the -z wsp, arguments
* and it creates a new instance to store statistics in and registers this
* new instance for the wsp tap.
*/
@@ -272,7 +272,7 @@ wspstat_init(const char *optarg, void* userdata _U_)
g_free(sp);
g_hash_table_foreach( sp->hash, (GHFunc) wsp_free_hash_table, NULL ) ;
g_hash_table_destroy( sp->hash );
- fprintf(stderr, "tethereal: Couldn't register wsp,stat tap: %s\n",
+ fprintf(stderr, "twireshark: Couldn't register wsp,stat tap: %s\n",
error_string->str);
g_string_free(error_string, TRUE);
exit(1);
@@ -22,8 +22,8 @@
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/
-/* This module provides WSP statistics to tethereal.
- * It is only used by tethereal and not ethereal
+/* This module provides WSP statistics to twireshark.
+ * It is only used by twireshark and not wireshark
*
*/
@@ -168,10 +168,10 @@ wspstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const
}
-/* This callback is used when tethereal wants us to draw/update our
- * data to the output device. Since this is tethereal only output is
+/* This callback is used when twireshark wants us to draw/update our
+ * data to the output device. Since this is twireshark only output is
* stdout.
@@ -168,10 +168,10 @@ wspstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const
* stdout.
- * Tethereal will only call this callback once, which is when tethereal has
+ * Twireshark will only call this callback once, which is when twireshark has
* finished reading all packets and exists.
* If used with wireshark this may be called any time, perhaps once every 3
@@ -209,7 +209,7 @@ wspstat_draw(void *psp)
* program and version are whick onc-rpc program/version we want to
* collect statistics for.
- * This function is called from tethereal when it parses the -z wsp, arguments
+ * This function is called from twireshark when it parses the -z wsp, arguments
* and it creates a new instance to store statistics in and registers this
* new instance for the wsp tap.